@@ -98,10 +98,12 @@ resp_spct <-
               num.spectra, " spectra")
       return(NA_real_)
     }
-    if (is_normalized(spct) || is_scaled(spct)) {
-      warning("The spectral data has been normalized or scaled, ",
-              "making impossible to calculate integrated response")
-      return(NA)
+    if (is_normalized(spct)) {
+      warning("The spectral data has been normalized, making impossible to calculate absorbance")
+      return(NA_real_)
+    }
+    if (is_scaled(spct)) {
+      warning("Summary calculated from rescaled data")
     }
     # makes "quantum" synonym for "photon" without changes to other code
     if (unit.out == "quantum") {
